@@ -1,4 +1,4 @@
 # flake8: noqa: F401
 from ._version import version as __version__
-from .holo import OffAxisHologram
+from .interfere import OffAxisHologram, QLSInterferogram
 from . import fourier
